diff --git a/modules/mol/alg/pymod/ligand_scoring_base.py b/modules/mol/alg/pymod/ligand_scoring_base.py
index eeb092d4525af8c53aa20413ccb57a52e53884a3..0e61a02c9295f48b96f31f093cb251e488d5d447 100644
--- a/modules/mol/alg/pymod/ligand_scoring_base.py
+++ b/modules/mol/alg/pymod/ligand_scoring_base.py
@@ -589,12 +589,12 @@ class LigandScorer:
           This indicates different stoichiometries.
         * `no_contact` (lDDT-PLI only): There were no lDDT contacts between
           the binding site and the ligand, and lDDT-PLI is undefined.
-        * `binding_site` (SCRMSD only): no residues were in proximity of the
-          target ligand.
-        * `model_representation` (SCRMSD only): no representation of
-          the reference binding site was found in the model. Either the binding
-          site was not modeled or the model ligand was positioned too far in
-          combination with `full_bs_search=False`.
+        * `target_binding_site` (SCRMSD only): no polymer residues were in
+          proximity of the target ligand.
+        * `model_binding_site` (SCRMSD only): the binding site was not found
+          in the model. Either the binding site was not modeled or the model
+          ligand was positioned too far in combination with
+          `full_bs_search=False`.
 
         :param trg_lig_idx: Index of target ligand
         :type trg_lig_idx: :class:`int`
@@ -673,14 +673,13 @@ class LigandScorer:
           This indicates different stoichiometries.
         * `no_contact` (lDDT-PLI only): There were no lDDT contacts between
           the binding site and the ligand, and lDDT-PLI is undefined.
-        * `binding_site` (SCRMSD only): a potential assignment was found in the
-          target, but there were no polymer residues in proximity of the ligand
-          in the target.
-        * `model_representation` (SCRMSD only): a potential assignment was
-          found in the target, but no representation of the binding site was
-          found in the model. Either the binding site was not modeled or the
-          model ligand was positioned too far in combination with
-          `full_bs_search=False`.
+        * `target_binding_site` (SCRMSD only): a potential assignment was found
+          in the target, but there were no polymer residues in proximity of the
+          ligand in the target.
+        * `model_binding_site` (SCRMSD only): a potential assignment was
+          found in the target, but no binding site was found in the model.
+          Either the binding site was not modeled or the model ligand was
+          positioned too far in combination with `full_bs_search=False`.
 
         :param mdl_lig_idx: Index of model ligand
         :type mdl_lig_idx: :class:`int`
diff --git a/modules/mol/alg/pymod/ligand_scoring_scrmsd.py b/modules/mol/alg/pymod/ligand_scoring_scrmsd.py
index 5dc6e61e815c494b70641211e6bb603ed9770e17..9ae0546d6ac62e88237bdb6aba89ad5792683de5 100644
--- a/modules/mol/alg/pymod/ligand_scoring_scrmsd.py
+++ b/modules/mol/alg/pymod/ligand_scoring_scrmsd.py
@@ -146,14 +146,13 @@ class SCRMSDScorer(ligand_scoring_base.LigandScorer):
         self._get_repr_input = dict()
 
         # update state decoding from parent with subclass specific stuff
-        self.state_decoding[10] = ("binding_site",
+        self.state_decoding[10] = ("target_binding_site",
                                    "No residues were in proximity of the "
                                    "target ligand.")
-        self.state_decoding[11] = ("model_representation", "No representation "
-                                   "of the reference binding site was found in "
-                                   "the model, i.e. the binding site was not "
-                                   "modeled or the model ligand was positioned "
-                                   "too far in combination with "
+        self.state_decoding[11] = ("model_binding_site", "Binding site was not"
+                                   " found in the model, i.e. the binding site"
+                                   " was not modeled or the model ligand was "
+                                   "positioned too far in combination with "
                                    "full_bs_search=False.")
         self.state_decoding[20] = ("unknown",
                                    "Unknown error occured in SCRMSDScorer")
diff --git a/modules/mol/alg/tests/test_ligand_scoring.py b/modules/mol/alg/tests/test_ligand_scoring.py
index 64f0b580183c79332f958f7ed049cbd3cda2c3e8..90cb8f81524d7c259bf2d7cbf1891745b8601b30 100644
--- a/modules/mol/alg/tests/test_ligand_scoring.py
+++ b/modules/mol/alg/tests/test_ligand_scoring.py
@@ -646,7 +646,7 @@ class TestLigandScoringFancy(unittest.TestCase):
         trg_report, trg_pair_report = sc.get_target_ligand_state_report(0)
 
         exp_lig_report = {'state': 10.0,
-                          'short desc': 'binding_site',
+                          'short desc': 'target_binding_site',
                           'desc': 'No residues were in proximity of the target ligand.'}
 
         exp_pair_report = [{'state': 1, 'short desc': 'identity',
@@ -856,18 +856,18 @@ class TestLigandScoringFancy(unittest.TestCase):
 
 
         self.assertDictEqual(sc.unassigned_model_ligands_reasons, {
-            'L_ZN': {1: 'model_representation'},
-            'L_NA': {1: 'binding_site'},
+            'L_ZN': {1: 'model_binding_site'},
+            'L_NA': {1: 'target_binding_site'},
             'L_OXY': {1: 'identity'},
             'L_MG_2': {1: 'stoichiometry'},
             "L_CMO": {1: 'disconnected'}
         })
         self.assertDictEqual(sc.unassigned_target_ligands_reasons, {
             'G': {1: 'identity'},
-            'H': {1: 'model_representation'},
+            'H': {1: 'model_binding_site'},
             'J': {1: 'stoichiometry'},
             'K': {1: 'identity'},
-            'L_NA': {1: 'binding_site'},
+            'L_NA': {1: 'target_binding_site'},
             "L_CMO": {1: 'disconnected'}
         })
         self.assertTrue("L_OXY" not in sc.score)
@@ -891,23 +891,23 @@ class TestLigandScoringFancy(unittest.TestCase):
 
         # Test with partial bs search (full_bs_search=True)
         # Here we expect L_MG_2 to be unassigned because of stoichiometry
         # rather than model_representation, as it no longer matters so far from
         # the binding site.
         sc = ligand_scoring_scrmsd.SCRMSDScorer(mdl, trg, None, None,
                                                full_bs_search=True)
         self.assertEqual(sc.unassigned_model_ligands_reasons, {
-            'L_ZN': {1: 'model_representation'},
-            'L_NA': {1: 'binding_site'},
+            'L_ZN': {1: 'model_binding_site'},
+            'L_NA': {1: 'target_binding_site'},
             'L_OXY': {1: 'identity'},
             'L_MG_2': {1: 'stoichiometry'},
             "L_CMO": {1: 'disconnected'}
         })
         self.assertEqual(sc.unassigned_target_ligands_reasons, {
             'G': {1: 'identity'},
-            'H': {1: 'model_representation'},
+            'H': {1: 'model_binding_site'},
             'J': {1: 'stoichiometry'},
             'K': {1: 'identity'},
-            'L_NA': {1: 'binding_site'},
+            'L_NA': {1: 'target_binding_site'},
             "L_CMO": {1: 'disconnected'}
         })
@@ -891,23 +891,23 @@ class TestLigandScoringFancy(unittest.TestCase):
         # Test with partial bs search (full_bs_search=True)
         # Here we expect L_MG_2 to be unassigned because of stoichiometry
-        # rather than model_representation, as it no longer matters so far from
+        # rather than model_binding_site, as it no longer matters so far from
         # the binding site.
         sc = ligand_scoring_scrmsd.SCRMSDScorer(mdl, trg, None, None,